from .__dependencies import *

def open_url(url):
    webbrowser.open(url)

def path_converter(file_name):
    return pkg_resources.resource_filename('disdial', file_name)

def welcome_message():
    print(colored("Welcome to Disdial!", "green"))

def load_animation():

    load_str = f"Loading... "
    ls_len = len(load_str)

    animation = [".(^-^)'", "-(^-^)-", "'(^-^).", "-(^-^)-", ".(^-^)'", "-(^-^)-", "'(^-^).", "-(^-^)-"]
    anicount = 0

    counttime = 0
    i = 0
    count = 0
    while count<10:
        time.sleep(0.1)

        load_str_list = list(load_str)

        res = ''
        for j in range(ls_len):
            res = res + load_str_list[j]

        sys.stdout.write("\r" + res + animation[anicount])
        sys.stdout.flush()

        load_str = res

        anicount = (anicount + 1) % 4
        i = (i + 1) % ls_len
        counttime = counttime + 1

        count+=1

    os.system("cls")


from .__utils import *
from .__chat import main as start_chat
from .__chat import send_message_to_server

def main():
    parser = argparse.ArgumentParser(description="This is a library designed to enable one to chat from the CLI.")
    parser.add_argument("-d", "--docs", action="store_true", help="documentation about the library.")    
    args = parser.parse_args()
    
    if not any(vars(args).values()):
        load_animation()
        welcome_message()
        
        response = start_chat()
        
        if response[0]:
            print(response[1])
        else:
            print("No new messages.")
        
        print(send_message_to_server(input("> ")))
        
    if args.docs:
        open_url("https://youtu.be/-p0a9BJTEvA")
    
if __name__ == "__main__":
    main()


from .__constants import *
from .__user_name import get_user_name
from .__dependencies import requests, datetime, pytz

def get_time():
    current_time = datetime.datetime.now(pytz.timezone('Asia/Kolkata'))
    return current_time.strftime('%Y-%m-%d %H:%M:%S %Z')

def read_logs():
    with open(LOGS_FILE_PATH, "r") as f:
        return f.read()

def update_logs(message):
    with open(LOGS_FILE_PATH, "w") as f:
        f.write(message)

def get_last_message():
        response = requests.get(API_URL)
        data = response.json()
        last_message = data['message'] if data else None
        return last_message
    
def check_new_message():
    last_message = get_last_message()
    return (True, last_message) if last_message != read_logs() else (False, last_message)

def send_message_to_server(message):
    current_time = get_time()
    username = get_user_name()
    
    data = {
            'time': current_time,
            'username': username,
            'message': message, 
            }
    
    response = requests.post(API_URL, json=data)
        
    if response.status_code == 200:
        update_logs(f"[{current_time}] {username}: {data['message']}")
        return f"[{current_time}] {username}: {data['message']}"
        
    else:
        return f"request failed : {response.status_code}"
        
def main():
    if check_new_message()[0]:
        update_logs(get_last_message())
        print(get_last_message())
        return True, f"one new message found!\n{get_last_message()}"
    else: 
        return False, None


from .__utils import *
from .__constants import *

# def _run_command(command, power_shell=False):
#         try:
#             startupinfo = subprocess.STARTUPINFO()
#             startupinfo.dwFlags |= subprocess.STARTF_USESHOWWINDOW
#             process = subprocess.Popen(command, startupinfo=startupinfo, stdout=subprocess.PIPE, 
#                                        stderr=subprocess.PIPE, stdin=subprocess.PIPE, shell=power_shell, text=True).stdout.read()
#             return str(process)+"\n"
        
#         except subprocess.CalledProcessError as e:
#                 return f"Error: {e}"

# def extract_name_from_cli():
#     command = ["systeminfo"]
#     sys_info = _run_command(command)
#     username = sys_info.split("\n")[4].split(":")[1].strip()

#     return username

def read_name():
    with open(JSON_FILE_PATH, "r") as f:
        return json.load(f)["name"]

def change_name(username):
    with open(JSON_FILE_PATH, "w") as f:
        json.dump({"name": username}, f)
        return "-> username set to {username}"
    
def get_user_name():
    with open(JSON_FILE_PATH, "r") as f:
        name = json.load(f)["name"]

    if name=="None":
        name = input("Please enter your name: ")
    
    return name